@@ -2,7 +2,7 @@
 use anyhow::Result;
 
 use genact::args::parse_args;
-use genact::{run, INSTANT_PRINT_LINES, SPEED_FACTOR};
+use genact::{INSTANT_PRINT_LINES, SPEED_FACTOR, run};
 
 use std::sync::atomic::Ordering;
 
@@ -15,8 +15,6 @@ async fn main() -> Result<()> {
     use clap::CommandFactory;
     use genact::args::AppConfig;
 
-    yansi::Paint::enable_windows_ascii();
-
     let appconfig = parse_args();
 
     if let Some(shell) = appconfig.print_completions {
