@@ -1,11 +1,13 @@
-//! Petend to do some downloading
-use async_trait::async_trait;
-use humansize::{format_size, FormatSizeOptions};
-use humantime::format_duration;
-use rand::prelude::*;
+//! Pretend to do some downloading
 use std::cmp::max;
 use std::time::Duration;
 
+use async_trait::async_trait;
+use humansize::{FormatSizeOptions, format_size};
+use humantime::format_duration;
+use rand::seq::IndexedRandom;
+use rand::{Rng, rng};
+
 use crate::args::AppConfig;
 use crate::data::{CFILES_LIST, EXTENSIONS_LIST};
 use crate::generators::gen_file_name_with_ext;
@@ -26,7 +28,7 @@ impl Module for Download {
     }
 
     async fn run(&self, appconfig: &AppConfig) {
-        let mut rng = thread_rng();
+        let mut rng = rng();
 
         // We'll use the same extension for all files of this whole run to make things seem more
         // realistic.
@@ -34,13 +36,13 @@ impl Module for Download {
 
         // Choose speed. We'll choose an approximate speed that we'll vary a little bit.
         // Download speed in bytes per second.
-        let download_speed = rng.gen_range(10_000_000..100_000_000);
+        let download_speed = rng.random_range(10_000_000..100_000_000);
 
-        let num_files = rng.gen_range(3..10);
+        let num_files = rng.random_range(3..10);
 
         for _ in 0..num_files {
             // File size in bytes.
-            let file_bytes = rng.gen_range(30_000_000..300_000_000);
+            let file_bytes = rng.random_range(30_000_000..300_000_000);
 
             // How long to sleep for in ms.
             let sleep_millis = 50;
@@ -64,7 +66,7 @@ impl Module for Download {
 
             let mut bytes_downloaded = 0u64;
             loop {
-                let download_speed_offset = rng.gen_range(-5_000_000i32..5_000_000i32);
+                let download_speed_offset = rng.random_range(-5_000_000i32..5_000_000i32);
                 let actual_download_speed =
                     max(100_000, download_speed + download_speed_offset) as u64;
                 let percent = ((100.0 / file_bytes as f64) * bytes_downloaded as f64).min(100.0);
