@@ -1,8 +1,10 @@
 //! Pretend to update julia packages
+use std::fmt::Display;
+
 use async_trait::async_trait;
 use instant::Instant;
-use rand::prelude::*;
-use std::fmt::Display;
+use rand::seq::IndexedRandom;
+use rand::{Rng, rng};
 use yansi::Paint;
 
 use crate::args::AppConfig;
@@ -31,19 +33,19 @@ impl Module for Julia {
     }
 
     async fn run(&self, appconfig: &AppConfig) {
-        let mut rng = thread_rng();
+        let mut rng = rng();
 
         // Choose `num_packages` packages and `num_artifacts` artifacts
         // non-repeating and in random order
-        let num_packages = rng.gen_range(10..150);
-        let num_artifacts = rng.gen_range(1..10);
+        let num_packages = rng.random_range(10..150);
+        let num_artifacts = rng.random_range(1..10);
         let all_packages: Vec<&Package> = JULIA_PACKAGES_LIST
             .choose_multiple(&mut rng, num_packages + num_artifacts)
             .collect();
         let (packages, artifacts) = all_packages.split_at(num_packages);
 
         // root project of the julia session
-        let project = if rng.gen_bool(0.3) {
+        let project = if rng.random_bool(0.3) {
             "@v1.7"
         } else {
             JULIA_PACKAGES_LIST.choose(&mut rng).unwrap().name
@@ -51,71 +53,71 @@ impl Module for Julia {
 
         // julia startup
         print_banner().await;
-        csleep(rng.gen_range(50..150)).await;
+        csleep(rng.random_range(50..150)).await;
         newline().await;
         print_julia_prompt().await;
 
         // wait user input
-        csleep(rng.gen_range(500..2500)).await;
+        csleep(rng.random_range(500..2500)).await;
 
         // enter pkg mode
         erase_line().await;
         print_pkg_prompt(project).await;
 
         // wait user input
-        csleep(rng.gen_range(500..1500)).await;
+        csleep(rng.random_range(500..1500)).await;
 
         // type "update" and press enter
-        dprint("up", rng.gen_range(100..500)).await;
-        dprint("date", rng.gen_range(100..500)).await;
-        csleep(rng.gen_range(500..1500)).await;
+        dprint("up", rng.random_range(100..500)).await;
+        dprint("date", rng.random_range(100..500)).await;
+        csleep(rng.random_range(500..1500)).await;
         newline().await;
 
         // wait Pkg.update() startup time
-        csleep(rng.gen_range(200..1000)).await;
+        csleep(rng.random_range(200..1000)).await;
 
         log_action("Updating", "registry at `~/.julia/registries/General.toml`").await;
-        csleep(rng.gen_range(1500..5000)).await;
+        csleep(rng.random_range(1500..5000)).await;
 
         log_action("Resolving", "package versions...").await;
-        csleep(rng.gen_range(500..2500)).await;
+        csleep(rng.random_range(500..2500)).await;
 
         install_packages(packages).await;
-        csleep(rng.gen_range(250..1000)).await;
+        csleep(rng.random_range(250..1000)).await;
 
         download_artifacts(artifacts).await;
-        csleep(rng.gen_range(250..1000)).await;
+        csleep(rng.random_range(250..1000)).await;
 
         update_project_and_manifest(project).await;
-        csleep(rng.gen_range(10..100)).await;
+        csleep(rng.random_range(10..100)).await;
 
         report_packages(packages).await;
-        csleep(rng.gen_range(150..500)).await;
+        csleep(rng.random_range(150..500)).await;
 
         build_artifacts(artifacts).await;
-        csleep(rng.gen_range(150..500)).await;
+        csleep(rng.random_range(150..500)).await;
 
         precompile(packages).await;
 
-        if rng.gen_bool(0.25) {
+        if rng.random_bool(0.25) {
             gc().await;
         }
 
         // wait cleanup
-        csleep(rng.gen_range(50..250)).await;
+        csleep(rng.random_range(50..250)).await;
 
         newline().await;
         print_pkg_prompt(project).await;
 
         // wait user input
-        csleep(rng.gen_range(500..5000)).await;
+        csleep(rng.random_range(500..5000)).await;
 
         // exit pkg mode
         erase_line().await;
         print_julia_prompt().await;
 
         // wait user input
-        csleep(rng.gen_range(1000..7000)).await;
+        csleep(rng.random_range(1000..7000)).await;
 
         // quit julia
         newline().await;
@@ -155,15 +157,11 @@ async fn print_julia_prompt() {
 }
 
 async fn print_pkg_prompt(project: &str) {
-    print(format!(
-        "{} ",
-        Paint::blue(format!("({project}) pkg>")).bold()
-    ))
-    .await;
+    print(format!("{} ", format!("({project}) pkg>").blue().bold())).await;
 }
 
 async fn log_action(action: impl Display, message: impl Display) {
-    print(format!("{:>12} {}", Paint::green(action).bold(), message)).await;
+    print(format!("{:>12} {}", action.green().bold(), message)).await;
     newline().await;
 }
 
@@ -173,7 +171,7 @@ async fn log_progress(bar: &progress_string::Bar) {
 }
 
 async fn install_packages(packages: &[&Package<'_>]) {
-    let mut rng = thread_rng();
+    let mut rng = rng();
 
     let max_name_length = packages.iter().map(|p| p.name.len()).max().unwrap();
     for package in packages {
@@ -185,15 +183,15 @@ async fn install_packages(packages: &[&Package<'_>]) {
             version = package.versions.last().unwrap()
         );
 
-        if rng.gen_bool(0.1) {
+        if rng.random_bool(0.1) {
             log_action("Installing", &package_and_version).await;
 
-            csleep(rng.gen_range(250..1000)).await;
+            csleep(rng.random_range(250..1000)).await;
 
             cursor_up(1).await;
             erase_line().await;
         } else {
-            csleep(rng.gen_range(10..200)).await;
+            csleep(rng.random_range(10..200)).await;
         }
 
         log_action("Installed", &package_and_version).await;
@@ -201,14 +199,14 @@ async fn install_packages(packages: &[&Package<'_>]) {
 }
 
 async fn download_artifacts(artifacts: &[&Package<'_>]) {
-    let mut rng = thread_rng();
+    let mut rng = rng();
 
     for artifact in artifacts {
-        csleep(rng.gen_range(50..100)).await;
+        csleep(rng.random_range(50..100)).await;
 
         log_action("Downloading", format!("artifact: {}", artifact.name)).await;
 
-        csleep(rng.gen_range(100..150)).await;
+        csleep(rng.random_range(100..150)).await;
 
         let mut bar = progress_string::BarBuilder::new()
             .total(10000)
@@ -221,7 +219,7 @@ async fn download_artifacts(artifacts: &[&Package<'_>]) {
         newline().await;
 
         while bar.current_partial < bar.total {
-            let add = rng.gen_range(0..=500.min(bar.total - bar.current_partial));
+            let add = rng.random_range(0..=500.min(bar.total - bar.current_partial));
             bar.update(add);
 
             cursor_up(1).await;
@@ -229,11 +227,11 @@ async fn download_artifacts(artifacts: &[&Package<'_>]) {
             print(format!("{:>15} {}", Paint::cyan("Downloading").bold(), bar)).await;
             newline().await;
 
-            csleep(rng.gen_range(50..75)).await;
+            csleep(rng.random_range(50..75)).await;
         }
         cursor_up(1).await;
         erase_line().await;
-        csleep(rng.gen_range(100..200)).await;
+        csleep(rng.random_range(100..200)).await;
         cursor_up(1).await;
         erase_line().await;
 
@@ -242,7 +240,7 @@ async fn download_artifacts(artifacts: &[&Package<'_>]) {
 }
 
 async fn update_project_and_manifest(project: &str) {
-    let mut rng = thread_rng();
+    let mut rng = rng();
 
     let project_path;
     let manifest_path;
@@ -255,19 +253,19 @@ async fn update_project_and_manifest(project: &str) {
         manifest_path = format!("~/Documents/code/julia/projects/{project}.jl/Manifest.toml");
     }
 
-    let old_format = rng.gen_bool(0.25);
+    let old_format = rng.random_bool(0.25);
 
     if old_format {
         print_old_manifest_format_before(&manifest_path).await;
     }
 
-    if rng.gen_bool(0.9) {
+    if rng.random_bool(0.9) {
         log_action("Updating", format!("`{project_path}`")).await;
     } else {
         log_action("No Changes", format!("to `{project_path}`")).await;
     }
 
-    csleep(rng.gen_range(10..100)).await;
+    csleep(rng.random_range(10..100)).await;
 
     log_action("Updating", format!("`{manifest_path}`")).await;
 
@@ -285,89 +283,88 @@ async fn print_old_manifest_format_before(manifest_path: &str) {
     .await;
     newline().await;
     print(format!(
-        "{} To update to the new format run `Pkg.upgrade_manifest()` which will upgrade the format without re-resolving.",
-        Paint::yellow("│").bold()
+            "{} To update to the new format run `Pkg.upgrade_manifest()` which will upgrade the format without re-resolving.",
+            Paint::yellow("│").bold()
     ))
-    .await;
+        .await;
     newline().await;
     print(format!(
-        "{} {}",
-        Paint::yellow("└").bold(),
-        Paint::fixed(8, "@ Pkg.Types /builddir/build/BUILD/julia-1.7.3/build/usr/share/julia/stdlib/v1.7/Pkg/src/manifest.jl:287")
+            "{} {}",
+            "└".yellow().bold(),
+            "@ Pkg.Types /builddir/build/BUILD/julia-1.7.3/build/usr/share/julia/stdlib/v1.7/Pkg/src/manifest.jl:287".fixed(8)
     ))
-    .await;
+        .await;
     newline().await;
 }
 
 async fn print_old_manifest_format_after(manifest_path: &str) {
     print(format!(
-        "{} The active manifest file is an older format with no julia version entry. Dependencies may have been resolved with a different julia version.",
-        Paint::yellow("┌ Warning:").bold(),
+            "{} The active manifest file is an older format with no julia version entry. Dependencies may have been resolved with a different julia version.",
+            Paint::yellow("┌ Warning:").bold(),
     ))
-    .await;
+        .await;
     newline().await;
     print(format!(
         "{} {}",
-        Paint::yellow("└").bold(),
-        Paint::fixed(8, format!("@ {manifest_path}:0"))
+        "└".yellow().bold(),
+        format!("@ {manifest_path}:0").fixed(8)
     ))
     .await;
     newline().await;
 }
 
 async fn report_packages(packages: &[&Package<'_>]) {
-    let mut rng = thread_rng();
+    let mut rng = rng();
 
     for package in packages {
-        if package.versions.len() > 1 && rng.gen_bool(0.75) {
+        if package.versions.len() > 1 && rng.random_bool(0.75) {
             // update package
+            let package_id = format!("[{}]", &package.id[0..8]);
+            let version_change = format!(
+                "↑ {} v{} ⇒ v{}",
+                package.name,
+                package.versions[rng.random_range(0..package.versions.len() - 1)],
+                package.versions.last().unwrap()
+            );
             print(format!(
                 "  {} {}",
-                Paint::fixed(8, format!("[{}]", &package.id[0..8])),
-                Paint::fixed(
-                    11, // bright yellow
-                    format!(
-                        "↑ {} v{} ⇒ v{}",
-                        package.name,
-                        package.versions[rng.gen_range(0..package.versions.len() - 1)],
-                        package.versions.last().unwrap()
-                    )
-                )
+                package_id.fixed(8),
+                version_change.fixed(11)
             ))
             .await;
             newline().await;
-        } else if rng.gen_bool(0.9) {
+        } else if rng.random_bool(0.9) {
             // add package
+            let package_id = format!("[{}]", &package.id[0..8]);
+            let version_change =
+                format!("+ {} v{}", package.name, package.versions.last().unwrap());
             print(format!(
                 "  {} {}",
-                Paint::fixed(8, format!("[{}]", &package.id[0..8])),
-                Paint::fixed(
-                    10, // bright green
-                    format!("+ {} v{}", package.name, package.versions.last().unwrap())
-                )
+                package_id.fixed(8),
+                version_change.fixed(10)
             ))
             .await;
             newline().await;
         } else {
             // remove package
+            let package_id = format!("[{}]", &package.id[0..8]);
+            let version_change =
+                format!("- {} v{}", package.name, package.versions.last().unwrap());
             print(format!(
                 "  {} {}",
-                Paint::fixed(8, format!("[{}]", &package.id[0..8])),
-                Paint::fixed(
-                    9, // bright red
-                    format!("- {} v{}", package.name, package.versions.last().unwrap())
-                )
+                package_id.fixed(8),
+                version_change.fixed(9)
             ))
             .await;
             newline().await;
         }
 
-        csleep(rng.gen_range(10..100)).await;
+        csleep(rng.random_range(10..100)).await;
     }
 }
 
 async fn build_artifacts(artifacts: &[&Package<'_>]) {
-    let mut rng = thread_rng();
+    let mut rng = rng();
 
     let mut bar = progress_string::BarBuilder::new()
         .total(artifacts.len())
@@ -404,7 +401,7 @@ async fn build_artifacts(artifacts: &[&Package<'_>]) {
 
         log_progress(&bar).await;
 
-        csleep(rng.gen_range(500..5000)).await;
+        csleep(rng.random_range(500..5000)).await;
     }
 
     // erase progress bar
@@ -413,7 +410,7 @@ async fn build_artifacts(artifacts: &[&Package<'_>]) {
 }
 
 async fn precompile(packages: &[&Package<'_>]) {
-    let mut rng = thread_rng();
+    let mut rng = rng();
 
     let num_packages = packages.len();
 
@@ -437,7 +434,7 @@ async fn precompile(packages: &[&Package<'_>]) {
         erase_line().await;
         log_progress(&bar).await;
 
-        csleep(rng.gen_range(50..1000)).await;
+        csleep(rng.random_range(50..1000)).await;
     }
 
     let elapsed = now.elapsed();
@@ -447,16 +444,16 @@ async fn precompile(packages: &[&Package<'_>]) {
     erase_line().await;
     print(format!(
             "  {num_packages} dependencies successfully precompiled in {seconds:.0} seconds ({} already precompiled)",
-            rng.gen_range(10..500)
-        ))
+            rng.random_range(10..500)
+    ))
         .await;
     newline().await;
 }
 
 async fn gc() {
-    let mut rng = thread_rng();
+    let mut rng = rng();
 
-    csleep(rng.gen_range(50..250)).await;
+    csleep(rng.random_range(50..250)).await;
 
     print(format!(
         "{} We haven't cleaned this depot up for a bit, running Pkg.gc()...",
@@ -465,62 +462,62 @@ async fn gc() {
     .await;
     newline().await;
 
-    csleep(rng.gen_range(100..250)).await;
+    csleep(rng.random_range(100..250)).await;
 
     log_action(
         "Active",
-        format!("manifest files: {} found", rng.gen_range(1..10)),
+        format!("manifest files: {} found", rng.random_range(1..10)),
     )
     .await;
 
-    csleep(rng.gen_range(100..250)).await;
+    csleep(rng.random_range(100..250)).await;
 
     log_action(
         "Active",
-        format!("artifact files: {} found", rng.gen_range(10..200)),
+        format!("artifact files: {} found", rng.random_range(10..200)),
     )
     .await;
 
-    csleep(rng.gen_range(100..250)).await;
+    csleep(rng.random_range(100..250)).await;
 
     log_action(
         "Active",
-        format!("scratchspaces: {} found", rng.gen_range(10..20)),
+        format!("scratchspaces: {} found", rng.random_range(10..20)),
     )
     .await;
 
-    csleep(rng.gen_range(100..250)).await;
+    csleep(rng.random_range(100..250)).await;
 
     log_action(
         "Deleted",
         format!(
             "{} package installations ({:.3} MiB)",
-            rng.gen_range(2..100),
-            rng.gen_range(10f32..250f32)
+            rng.random_range(2..100),
+            rng.random_range(10f32..250f32)
         ),
     )
     .await;
 
-    csleep(rng.gen_range(100..250)).await;
+    csleep(rng.random_range(100..250)).await;
 
     log_action(
         "Deleted",
         format!(
             "{} artifact installations ({:.3} MiB)",
-            rng.gen_range(2..10),
-            rng.gen_range(10f32..250f32)
+            rng.random_range(2..10),
+            rng.random_range(10f32..250f32)
         ),
     )
     .await;
 
-    csleep(rng.gen_range(100..250)).await;
+    csleep(rng.random_range(100..250)).await;
 
     log_action(
         "Deleted",
         format!(
             "{} scratchspaces ({:.3} byte)",
-            rng.gen_range(2..10),
-            rng.gen_range(10f32..1000f32)
+            rng.random_range(2..10),
+            rng.random_range(10f32..1000f32)
         ),
     )
     .await;
