@@ -1,7 +1,7 @@
 //! Pretend to run mkinitcpio
 use async_trait::async_trait;
-use rand::prelude::*;
-use rand::seq::SliceRandom;
+use rand::seq::IndexedRandom;
+use rand::{Rng, rng};
 use regex::Regex;
 use yansi::Paint;
 
@@ -59,7 +59,7 @@ async fn build(
     os_release: &str,
     appconfig: &AppConfig,
 ) {
-    let mut rng = thread_rng();
+    let mut rng = rng();
 
     msg1(
         format!("Building image from preset: /etc/mkinitcpio.d/{preset}.preset: '{mode}'",)
@@ -82,7 +82,7 @@ async fn build(
 
     for hook in hooks {
         msg2(format!("Running build hook: [{hook}]").as_ref()).await;
-        csleep(rng.gen_range(50..1000)).await;
+        csleep(rng.random_range(50..1000)).await;
 
         if *hook == "block" && mode == "fallback" {
             for driver in drivers {
@@ -96,10 +96,10 @@ async fn build(
     }
 
     msg1("Generating module dependencies").await;
-    csleep(rng.gen_range(200..500)).await;
+    csleep(rng.random_range(200..500)).await;
 
     msg1(format!("Creating {zip}-compressed initcpio image: {image}",).as_ref()).await;
-    csleep(rng.gen_range(500..2500)).await;
+    csleep(rng.random_range(500..2500)).await;
 
     msg1("Image generation successful").await;
 }
@@ -117,14 +117,14 @@ impl Module for Mkinitcpio {
     }
 
     async fn run(&self, appconfig: &AppConfig) {
-        let mut rng = thread_rng();
+        let mut rng = rng();
 
         // Select a few hooks from the list of all hooks (in order). Make sure the required default
         // hooks are also included (also, in order).
         let hooks = {
             let mut ret: Vec<&str> = vec![];
             for hook in BOOT_HOOKS_LIST.iter() {
-                if REQUIRED_HOOKS.contains(hook) || rng.gen_range(0..10) < 3 {
+                if REQUIRED_HOOKS.contains(hook) || rng.random_range(0..10) < 3 {
                     ret.push(hook);
                 }
             }
@@ -139,7 +139,7 @@ impl Module for Mkinitcpio {
 
             let re = Regex::new(r"^drivers/scsi.*/([^/\.]+).c$").unwrap();
 
-            let count = rng.gen_range(0..5);
+            let count = rng.random_range(0..5);
             while ret.len() < count {
                 let file = CFILES_LIST.choose(&mut rng).unwrap();
 
